@@ -27,13 +27,6 @@
 #' @param na_replace The value used to replace `NA` values in `supertbl`. The default is "".
 #' @param overwrite If `FALSE`, will not overwrite `file` when it exists. The default is `FALSE`.
 #'
-#' @importFrom purrr map map2
-#' @importFrom stringr str_trunc str_replace_all str_squish
-#' @importFrom dplyr select pull
-#' @importFrom rlang check_installed
-#' @importFrom lubridate is.period is.difftime
-#' @importFrom tidyselect where
-#'
 #' @return
 #' An `openxlsx2` workbook object, invisibly
 #'
@@ -158,8 +151,8 @@ write_redcap_xlsx <- function(supertbl,
 
       wb$add_data_table(
         sheet = y, x = x,
-        startRow = ifelse(add_labelled_column_headers, 2, 1),
-        tableStyle = table_style,
+        start_row = ifelse(add_labelled_column_headers, 2, 1),
+        table_style = table_style,
         na.strings = na_replace
       )
     }
@@ -205,8 +198,8 @@ write_redcap_xlsx <- function(supertbl,
   }
 
   # Export workbook object ----
-  wb$set_bookview(windowHeight = 130000, windowWidth = 6000)
-  wb$save(path = file, overwrite = overwrite)
+  wb$set_bookview(window_height = 130000, window_width = 6000)
+  wb$save(file = file, overwrite = overwrite)
 }
 
 #' @title Add labelled features to write_redcap_xlsx
@@ -226,12 +219,6 @@ write_redcap_xlsx <- function(supertbl,
 #' @param supertbl_toc The table of contents supertibble defined in the parent
 #' function. Default `NULL`.
 #'
-#' @importFrom purrr map pluck
-#' @importFrom tidyr pivot_wider
-#' @importFrom dplyr select filter relocate mutate if_else
-#' @importFrom rlang check_installed .data
-#' @importFrom tidyselect any_of
-#'
 #' @keywords internal
 
 add_labelled_xlsx_features <- function(supertbl,
@@ -262,7 +249,7 @@ add_labelled_xlsx_features <- function(supertbl,
 
     wb$add_data(
       sheet = "Table of Contents",
-      x = supertbl_labels, colNames = FALSE
+      x = supertbl_labels, col_names = FALSE
     )
   }
 
@@ -292,7 +279,7 @@ add_labelled_xlsx_features <- function(supertbl,
 
     wb$add_data(
       sheet = "REDCap Metadata",
-      x = supertbl_meta_labs, colNames = FALSE
+      x = supertbl_meta_labs, col_names = FALSE
     )
   }
 
@@ -302,7 +289,7 @@ add_labelled_xlsx_features <- function(supertbl,
   for (i in seq_along(supertbl$redcap_form_name)) {
     wb$add_data(
       sheet = sheet_vals[i],
-      x = var_labels[[i]], colNames = FALSE
+      x = var_labels[[i]], col_names = FALSE
     )
   }
 
@@ -312,7 +299,7 @@ add_labelled_xlsx_features <- function(supertbl,
     wb$add_cell_style(
       sheet = i,
       dims = dims,
-      wrapText = "1"
+      wrap_text = "1"
     )
     wb$add_font(
       sheet = i,
@@ -340,9 +327,6 @@ add_labelled_xlsx_features <- function(supertbl,
 #' "auto", otherwise a numeric value. Standard Excel is 8.43.
 #' @param na_replace The value used to replace `NA` values in `supertbl`. The default is "".
 #'
-#' @importFrom dplyr select mutate row_number across
-#' @importFrom tidyselect any_of
-#'
 #' @returns A dataframe
 #'
 #' @keywords internal
@@ -396,8 +380,8 @@ add_supertbl_toc <- function(wb,
   wb$add_data_table(
     sheet = "Table of Contents",
     x = supertbl_toc,
-    startRow = ifelse(add_labelled_column_headers, 2, 1),
-    tableStyle = table_style,
+    start_row = ifelse(add_labelled_column_headers, 2, 1),
+    table_style = table_style,
     na.strings = na_replace
   )
   wb$set_col_widths(
@@ -426,9 +410,6 @@ add_supertbl_toc <- function(wb,
 #' "auto", otherwise a numeric value. Standard Excel is 8.43.
 #' @param na_replace The value used to replace `NA` values in `supertbl`. The default is "".
 #'
-#' @importFrom dplyr select filter
-#' @importFrom tidyr unnest
-#'
 #' @returns A dataframe
 #'
 #' @keywords internal
@@ -444,8 +425,8 @@ add_metadata_sheet <- function(supertbl,
   wb$add_data_table(
     sheet = "REDCap Metadata",
     x = supertbl_meta,
-    startRow = ifelse(add_labelled_column_headers, 2, 1),
-    tableStyle = table_style,
+    start_row = ifelse(add_labelled_column_headers, 2, 1),
+    table_style = table_style,
     na.strings = na_replace
   )
   wb$set_col_widths(
@@ -465,10 +446,6 @@ add_metadata_sheet <- function(supertbl,
 #' @param add_labelled_column_headers Whether or not to include labelled outputs
 #' @param call the calling environment to use in the warning message
 #'
-#' @importFrom cli cli_abort
-#' @importFrom rlang caller_env is_installed
-#' @importFrom purrr some
-#'
 #' @returns A boolean
 #'
 #' @keywords internal
@@ -527,10 +504,6 @@ check_labelled <- function(supertbl, add_labelled_column_headers, call = caller_
 #' @param supertbl_meta an `unnest`-ed metadata tibble from the supertibble
 #' @param add_labelled_column_headers Whether or not to include labelled outputs
 #'
-#' @importFrom dplyr mutate across case_when filter pull
-#' @importFrom purrr map
-#' @importFrom tidyselect any_of
-#'
 #' @keywords internal
 supertbl_recode <- function(supertbl, supertbl_meta, add_labelled_column_headers) {
   # Recode yesno from TRUE/FALSE to "yes"/"no"
@@ -584,11 +557,6 @@ supertbl_recode <- function(supertbl, supertbl_meta, add_labelled_column_headers
 #'
 #' @param supertbl A supertibble generated using `read_redcap()`
 #'
-#' @importFrom dplyr filter select mutate case_when pull
-#' @importFrom tidyr unnest
-#' @importFrom lubridate is.period is.difftime
-#' @importFrom tidyselect where
-#'
 #' @keywords internal
 
 bind_supertbl_metadata <- function(supertbl) {
